library animation_play_pause;

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:rive/rive.dart';
import 'package:flutter/services.dart';

/// A Calculator.
class Calculator {
  /// Returns [value] plus 1.
  int addOne(int value) => value + 1;
}

class ExampleStateMachine extends StatefulWidget {
  const ExampleStateMachine({Key? key}) : super(key: key);

  @override
  _ExampleStateMachineState createState() => _ExampleStateMachineState();
}

class _ExampleStateMachineState extends State<ExampleStateMachine> {
  /// Tracks if the animation is playing by whether controller is running.
  bool get isPlaying => _controller?.isActive ?? false;

  Artboard? _riveArtboard;
  StateMachineController? _controller;
  SMIInput<bool>? _playingInput;
  late RiveAnimationController _prevController;
  late RiveAnimationController _nextController;
  bool _isPlaying2 = false;
  bool _isPlaying3 = false;

  @override
  void initState() {
    super.initState();

    // Load the animation file from the bundle, note that you could also
    // download this. The RiveFile just expects a list of bytes.
    rootBundle.load('animations/PlayPause3.riv').then(
          (data) async {
        // Load the RiveFile from the binary data.
        final file = RiveFile.import(data);

        // The artboard is the root of the animation and gets drawn in the
        // Rive widget.
        final artboard = file.mainArtboard;
        var controller =
        StateMachineController.fromArtboard(artboard, 'State Machine 1');
        if (controller != null) {
          artboard.addController(controller);
          _playingInput = controller.findInput('playing');
        }
        setState(() => _riveArtboard = artboard);
      },
    );
    _prevController = OneShotAnimation(
      'prev',
      autoplay: false,
      onStop: () => setState(() => _isPlaying2 = false),
      onStart: () => setState(() => _isPlaying2 = true),
    );
    _nextController = OneShotAnimation(
      'next',
      autoplay: false,
      onStop: () => setState(() => _isPlaying3 = false),
      onStart: () => setState(() => _isPlaying3 = true),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: double.infinity,
      height: 200,
      child: Center(
        child: _riveArtboard == null
            ? const SizedBox()
            : Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            GestureDetector(
              onTap: () =>
              _isPlaying2 ? null : _prevController.isActive = true,
              child: SizedBox(
                width: 100,
                height: 100,
                child: RiveAnimation.asset(
                  'animations/PlayPause3.riv',
                  animations: const ['prev'],
                  controllers: [_prevController],
                ),
              ),
            ),
            GestureDetector(
              onTap: () {
                if (_playingInput!.value == true &&
                    _playingInput!.controller.isActive == false) {
                  _playingInput!.value = false;
                } else if (_playingInput!.value == false &&
                    _playingInput!.controller.isActive == false) {
                  _playingInput!.value = true;
                }
              },
              child: SizedBox(
                width: 100,
                height: 100,
                child: Rive(
                  artboard: _riveArtboard!,
                ),
              ),
            ),
            GestureDetector(
              onTap: () =>
              _isPlaying3 ? null : _nextController.isActive = true,
              child: SizedBox(
                width: 100,
                height: 100,
                child: RiveAnimation.asset(
                  'animations/PlayPause3.riv',
                  animations: const ['next'],
                  controllers: [_nextController],
                ),
              ),
            ),

          ],
        ),
      ),
    );
  }
}

